@@ -29,7 +29,6 @@
 #include <Lum/Text.h>
 #include <Lum/TextValue.h>
 #include <Lum/TimeSelect.h>
-#include <Lum/WindowGroup.h>
 
 #include "config.h"
 
@@ -68,16 +67,9 @@ public:
     ConvertUnix();
     ConvertLocal();
 
-    AttachModel(convertUnix);
-    AttachModel(convertLocal);
-    AttachModel(about);
-  }
-
-  ~MainWindow()
-  {
-    UnattachModel(about);
-    UnattachModel(convertLocal);
-    UnattachModel(convertUnix);
+    Observe(convertUnix);
+    Observe(convertLocal);
+    Observe(about);
   }
 
   void PreInit()
@@ -92,15 +84,12 @@ public:
     Lum::Text             *text;
     Lum::TextValue        *value;
     Lum::TimeSelect       *timeSel;
-    Lum::WindowGroup      *wGroup;
 
     Lum::Base::SystemTime now;
     std::wstring          tmp;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
-    tab=new Lum::Tab();;
+    tab=new Lum::Tab();
+    tab->SetFlex(true,true);
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,false);
@@ -110,8 +99,9 @@ public:
 
     string=new Lum::String();
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,Lum::Base::NumberDigits(std::numeric_limits<time_t>::max()));
+    string->SetModel(unixResult);
     string->SetAlignment(Lum::String::right);
-    string->SetModel(unixInput);
+    string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeDec));
     label->AddLabel(_(L"UNIX_TIME",L"Unix time:"),string);
 
     value=new Lum::TextValue();
@@ -204,6 +194,7 @@ public:
     tab->Add(_(L"INFO",L"Info"),text);
 
     panel=new Lum::VPanel();
+    panel->SetFlex(true,true);
 
     panel->Add(tab);
 
@@ -226,8 +217,7 @@ public:
 
     panel->Add(row);
 
-    wGroup->SetMain(panel);
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
